Scaling

Enum Scaling 

pub enum Scaling {
    Unscaled,
    Exponential,
}
Scaling option for Bessel and Airy function computation.

When Exponential is selected, the result is multiplied by an exponential factor to prevent overflow or underflow. The factor depends on the function type:

  • J, Y: exp(−|Im(z)|)
  • I: exp(−|Re(z)|)
  • K: exp(z)
  • H(1): exp(−iz)
  • H(2): exp(iz)
  • Ai, Ai′: exp(ζ)
  • Bi, Bi′: exp(−|Re(ζ)|)

where ζ = (2/3) · z · √z.

Variants



Unscaled

No scaling applied.



Exponential

Exponential scaling to prevent overflow/underflow.