AiryResult

Struct AiryResult 

pub struct AiryResult<T: BesselFloat> {
    pub value: Complex<T>,
    pub status: Accuracy,
}
Result of an Airy function computation, returned by _raw functions (e.g., airy_raw).

Simplified convenience functions (airy, biry, …) do not expose this type; they return only the computed value and discard the status.

Fields

value: Complex<T>

Computed function value.

status: Accuracy

Accuracy of the computation result.

See Accuracy for possible values and their meaning.